==> vacuum-1.0.1-source.tar.gz: vacuum-1.0.1/src/translations/pl_PL/filetransfer.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL" sourcelanguage="en">
<context>
    <name>FileTransfer</name>
    <message>
        <source>File Transfer</source>
        <translation>Transfer plików</translation>
    </message>
    <message>
        <source>Send File</source>
        <translation>Wyślij plik</translation>
    </message>
    <message>
        <source>File transfer completed</source>
        <translation>Przesyłanie plików zakończone</translation>
    </message>
    <message>
        <source>Requested file transfer: %1</source>
        <translation>Transfer pliku: %1</translation>
    </message>
    <message>
        <source>You received a request to transfer the file</source>
        <translation>Odebrano żądanie przesłania pliku</translation>
    </message>
    <message>
        <source>Completed transferring file: %1</source>
        <translation>Zakończono przesyłanie pliku : %1</translation>
    </message>
    <message>
        <source>Canceled transferring file: %1</source>
        <translation>Anulowano przesyłanie pliku: %1</translation>
    </message>
    <message>
        <source>File transfer canceled: %1</source>
        <translation>Anulowano transfer pliku: %1</translation>
    </message>
    <message>
        <source>Auto sending file: %1</source>
        <translation>Automatyczne wysyłanie pliku: %1</translation>
    </message>
    <message>
        <source>File sending is started automatically</source>
        <translation>Wysyłanie pliku rozpoczęto automatycznie</translation>
    </message>
    <message>
        <source>Auto receiving file: %1</source>
        <translation>Automatyczne odbieraniu pliku: %1</translation>
    </message>
    <message>
        <source>File receiving is started automatically</source>
        <translation>Odbieraniu pliku rozpoczęto automatycznie</translation>
    </message>
    <message>
        <source>Allows to send a file to another contact</source>
        <translation>Pozwala wysłać plik do innego kontaktu</translation>
    </message>
    <message>
        <source>Supports the sending of the file to another contact</source>
        <translation>Obsługa wysyłki pliku do innego kontaktu</translation>
    </message>
</context>
<context>
    <name>FileTransferOptionsClass</name>
    <message>
        <source>Automatically receive files from contacts in roster</source>
        <translation>Automatycznie pobieraj pliki od kontaktów w rosterze</translation>
    </message>
    <message>
        <source>Hide dialog after transfer started</source>
        <translation>Zamknij okno transferu kiedy zacznie się pobieranie</translation>
    </message>
    <message>
        <source>Automatically remove finished transfers</source>
        <translation>Automatycznie usuń ukończone transfery</translation>
    </message>
</context>
<context>
    <name>StreamDialog</name>
    <message>
        <source>Send File - %1</source>
        <translation>Wyślij plik - %1</translation>
    </message>
    <message>
        <source>Receive File - %1</source>
        <translation>Pobierz plik - %1</translation>
    </message>
    <message>
        <source>B</source>
        <comment>Byte</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KB</source>
        <comment>Kilobyte</comment>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <comment>Megabyte</comment>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <comment>Gigabyte</comment>
        <translation>GB</translation>
    </message>
    <message>
        <source>/sec</source>
        <translation>/sek</translation>
    </message>
    <message>
        <source>Select file for receive</source>
        <translation>Wybierz plik do pobrania</translation>
    </message>
    <message>
        <source>Continue file transfer</source>
        <translation>Kontynuuj transfer pliku</translation>
    </message>
    <message>
        <source>A file with this name, but a smaller size already exists. Do you want to continue file transfer?</source>
        <translation>Plik o tej nazwie, ale mniejszy, już istnieje. Chcesz kontynuować transfer pliku?</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>A file with this name already exists. Do you want to remove existing file?</source>
        <translation>Plik o tej nazwie już istnieje. Czy chcesz, aby usunąć istniejący plik?</translation>
    </message>
    <message>
        <source>Select file to send</source>
        <translation>Wybierz plik do wysłania</translation>
    </message>
    <message>
        <source>Unable to send request for file transfer, check settings and try again!</source>
        <translation>Nie można zainicjować przesyłania plików, sprawdź ustawienia i spróbuj ponownie!</translation>
    </message>
    <message>
        <source>Unable to start the file transfer, check settings and try again!</source>
        <translation>Nie można zacząć przesyłania plików, sprawdź ustawienia i spróbuj ponownie!</translation>
    </message>
    <message>
        <source>Are you sure you want to cancel a file transfer?</source>
        <translation>Jesteś pewien, że chcesz anulować przesyłanie pliku?</translation>
    </message>
    <message>
        <source>Cancel file transfer</source>
        <translation>Anuluj transfer pliku</translation>
    </message>
    <message>
        <source>Can not delete existing file</source>
        <translation>Nie można usunąć istniejącego pliku</translation>
    </message>
    <message>
        <source>Remove file</source>
        <translation>Usuń plik</translation>
    </message>
    <message>
        <source>Selected file does not exists</source>
        <translation>Wybrany plik nie istnieje</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>Do:</translation>
    </message>
    <message>
        <source>From:</source>
        <translation>Od:</translation>
    </message>
    <message>
        <source>Transfered %1 of %2.</source>
        <translation>Przesłano %1 z %2.</translation>
    </message>
    <message>
        <source>Speed %1.</source>
        <translation>Prędkość %1.</translation>
    </message>
    <message>
        <source>Selected data stream is not available</source>
        <translation>Wybrany strumień jest nie dostępny</translation>
    </message>
    <message>
        <source>Please select at least one data stream</source>
        <translation>Wybierz conajmniej jeden strumień</translation>
    </message>
    <message>
        <source>Data transmission terminated</source>
        <translation>Połączenie zostało przerwane</translation>
    </message>
</context>
<context>
    <name>StreamDialogClass</name>
    <message>
        <source>To/From:</source>
        <translation>Od/Do:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Plik:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Opis:</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Postęp:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Profile:</source>
        <translation>Profil:</translation>
    </message>
    <message>
        <source>Select data stream and settings profile</source>
        <translation>Wybierz strumień danych oraz profil ustawień</translation>
    </message>
</context>
</TS>

==> vacuum-1.0.2-source.tar.gz: vacuum-1.0.2/src/translations/pl_PL/filetransfer.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL" sourcelanguage="en">
<context>
    <name>FileTransfer</name>
    <message>
        <source>File Transfer</source>
        <translation>Transfer plików</translation>
    </message>
    <message>
        <source>Send File</source>
        <translation>Wyślij plik</translation>
    </message>
    <message>
        <source>File transfer completed</source>
        <translation>Przesyłanie plików zakończone</translation>
    </message>
    <message>
        <source>Requested file transfer: %1</source>
        <translation>Transfer pliku: %1</translation>
    </message>
    <message>
        <source>You received a request to transfer the file</source>
        <translation>Odebrano żądanie przesłania pliku</translation>
    </message>
    <message>
        <source>Completed transferring file: %1</source>
        <translation>Zakończono przesyłanie pliku : %1</translation>
    </message>
    <message>
        <source>Canceled transferring file: %1</source>
        <translation>Anulowano przesyłanie pliku: %1</translation>
    </message>
    <message>
        <source>File transfer canceled: %1</source>
        <translation>Anulowano transfer pliku: %1</translation>
    </message>
    <message>
        <source>Auto sending file: %1</source>
        <translation>Automatyczne wysyłanie pliku: %1</translation>
    </message>
    <message>
        <source>File sending is started automatically</source>
        <translation>Wysyłanie pliku rozpoczęto automatycznie</translation>
    </message>
    <message>
        <source>Auto receiving file: %1</source>
        <translation>Automatyczne odbieraniu pliku: %1</translation>
    </message>
    <message>
        <source>File receiving is started automatically</source>
        <translation>Odbieraniu pliku rozpoczęto automatycznie</translation>
    </message>
    <message>
        <source>Allows to send a file to another contact</source>
        <translation>Pozwala wysłać plik do innego kontaktu</translation>
    </message>
    <message>
        <source>Supports the sending of the file to another contact</source>
        <translation>Obsługa wysyłki pliku do innego kontaktu</translation>
    </message>
</context>
<context>
    <name>FileTransferOptionsClass</name>
    <message>
        <source>Automatically receive files from contacts in roster</source>
        <translation>Automatycznie pobieraj pliki od kontaktów w rosterze</translation>
    </message>
    <message>
        <source>Hide dialog after transfer started</source>
        <translation>Zamknij okno transferu kiedy zacznie się pobieranie</translation>
    </message>
    <message>
        <source>Automatically remove finished transfers</source>
        <translation>Automatycznie usuń ukończone transfery</translation>
    </message>
</context>
<context>
    <name>StreamDialog</name>
    <message>
        <source>Send File - %1</source>
        <translation>Wyślij plik - %1</translation>
    </message>
    <message>
        <source>Receive File - %1</source>
        <translation>Pobierz plik - %1</translation>
    </message>
    <message>
        <source>B</source>
        <comment>Byte</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KB</source>
        <comment>Kilobyte</comment>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <comment>Megabyte</comment>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <comment>Gigabyte</comment>
        <translation>GB</translation>
    </message>
    <message>
        <source>/sec</source>
        <translation>/sek</translation>
    </message>
    <message>
        <source>Select file for receive</source>
        <translation>Wybierz plik do pobrania</translation>
    </message>
    <message>
        <source>Continue file transfer</source>
        <translation>Kontynuuj transfer pliku</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>A file with this name already exists. Do you want to remove existing file?</source>
        <translation>Plik o tej nazwie już istnieje. Czy chcesz, aby usunąć istniejący plik?</translation>
    </message>
    <message>
        <source>Select file to send</source>
        <translation>Wybierz plik do wysłania</translation>
    </message>
    <message>
        <source>Unable to send request for file transfer, check settings and try again!</source>
        <translation>Nie można zainicjować przesyłania plików, sprawdź ustawienia i spróbuj ponownie!</translation>
    </message>
    <message>
        <source>Unable to start the file transfer, check settings and try again!</source>
        <translation>Nie można zacząć przesyłania plików, sprawdź ustawienia i spróbuj ponownie!</translation>
    </message>
    <message>
        <source>Are you sure you want to cancel a file transfer?</source>
        <translation>Jesteś pewien, że chcesz anulować przesyłanie pliku?</translation>
    </message>
    <message>
        <source>Cancel file transfer</source>
        <translation>Anuluj transfer pliku</translation>
    </message>
    <message>
        <source>Can not delete existing file</source>
        <translation>Nie można usunąć istniejącego pliku</translation>
    </message>
    <message>
        <source>Remove file</source>
        <translation>Usuń plik</translation>
    </message>
    <message>
        <source>Selected file does not exists</source>
        <translation>Wybrany plik nie istnieje</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>Do:</translation>
    </message>
    <message>
        <source>From:</source>
        <translation>Od:</translation>
    </message>
    <message>
        <source>Transfered %1 of %2.</source>
        <translation>Przesłano %1 z %2.</translation>
    </message>
    <message>
        <source>Speed %1.</source>
        <translation>Prędkość %1.</translation>
    </message>
    <message>
        <source>Selected data stream is not available</source>
        <translation>Wybrany strumień jest nie dostępny</translation>
    </message>
    <message>
        <source>Please select at least one data stream</source>
        <translation>Wybierz conajmniej jeden strumień</translation>
    </message>
    <message>
        <source>Data transmission terminated</source>
        <translation>Połączenie zostało przerwane</translation>
    </message>
    <message>
        <source>A file with this name, but a smaller size already exists.</source>
        <translation>Plik o tej nazwie, ale o mniejszym rozmiarze już istnieje.</translation>
    </message>
    <message>
        <source>If you want to change file name press &apos;Cancel&apos;</source>
        <translation>Jesli chcesz zmienić nazwę pliku wciśnij &apos;Anuluj&apos;</translation>
    </message>
    <message>
        <source>If you want to download the rest of file press &apos;Yes&apos;</source>
        <translation>Jeśli chcesz ściągnąć resztę pliku wciśnij &apos;Tak&apos;</translation>
    </message>
    <message>
        <source>If you want to start download from the beginning press &apos;Retry&apos;</source>
        <translation>Jeśli chcesz ściągać od początku naciśnij &apos;Powtórz&apos;</translation>
    </message>
</context>
<context>
    <name>StreamDialogClass</name>
    <message>
        <source>To/From:</source>
        <translation>Od/Do:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Plik:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Opis:</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Postęp:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Profile:</source>
        <translation>Profil:</translation>
    </message>
    <message>
        <source>Select data stream and settings profile</source>
        <translation>Wybierz strumień danych oraz profil ustawień</translation>
    </message>
</context>
</TS>
